from typing import Literal, Mapping, Optional, Union

from ..eorzea_lang import EorzeaLang

weather: Mapping[
    int,
    Mapping[
        Union[EorzeaLang, Literal["de", "en", "fr", "ja", "ko", "cn"]], Optional[str]
    ],
] = {
    0: {"cn": None, "de": None, "en": None, "fr": None, "ja": None, "ko": "●설명용 날씨"},
    1: {
        "cn": "碧空",
        "de": "Klar",
        "en": "Clear Skies",
        "fr": "Dégagé",
        "ja": "快晴",
        "ko": "쾌청",
    },
    2: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    3: {
        "cn": "阴云",
        "de": "Wolkig",
        "en": "Clouds",
        "fr": "Couvert",
        "ja": "曇り",
        "ko": "흐림",
    },
    4: {
        "cn": "薄雾",
        "de": "Neblig",
        "en": "Fog",
        "fr": "Brouillard",
        "ja": "霧",
        "ko": "안개",
    },
    5: {"cn": "微风", "de": "Windig", "en": "Wind", "fr": "Vent", "ja": "風", "ko": "바람"},
    6: {
        "cn": "强风",
        "de": "Stürmisch",
        "en": "Gales",
        "fr": "Vents violents",
        "ja": "暴風",
        "ko": "폭풍",
    },
    7: {
        "cn": "小雨",
        "de": "Regnerisch",
        "en": "Rain",
        "fr": "Pluie",
        "ja": "雨",
        "ko": "비",
    },
    8: {
        "cn": "暴雨",
        "de": "Wolkenbruch",
        "en": "Showers",
        "fr": "Pluie torrentielle",
        "ja": "暴雨",
        "ko": "폭우",
    },
    9: {
        "cn": "打雷",
        "de": "Gewittrig",
        "en": "Thunder",
        "fr": "Orages",
        "ja": "雷",
        "ko": "번개",
    },
    10: {
        "cn": "雷雨",
        "de": "Gewitter",
        "en": "Thunderstorms",
        "fr": "Orages violents",
        "ja": "雷雨",
        "ko": "뇌우",
    },
    11: {
        "cn": "扬沙",
        "de": "Staubig",
        "en": "Dust Storms",
        "fr": "Tempêtes de poussière",
        "ja": "砂塵",
        "ko": "모래먼지",
    },
    12: {
        "cn": "沙尘暴",
        "de": "Sandsturm",
        "en": "Sandstorms",
        "fr": "Tempêtes de sable",
        "ja": "砂嵐",
        "ko": "모래폭풍",
    },
    13: {
        "cn": "高温",
        "de": "Heiß",
        "en": "Hot Spells",
        "fr": "Chaud",
        "ja": "熱波",
        "ko": "열파",
    },
    14: {
        "cn": "热浪",
        "de": "Gluthitze",
        "en": "Heat Waves",
        "fr": "Torride",
        "ja": "灼熱波",
        "ko": "작열파",
    },
    15: {"cn": "小雪", "de": "Schnee", "en": "Snow", "fr": "Neige", "ja": "雪", "ko": "눈"},
    16: {
        "cn": "暴雪",
        "de": "Schneesturm",
        "en": "Blizzards",
        "fr": "Blizzard",
        "ja": "吹雪",
        "ko": "눈보라",
    },
    17: {
        "cn": "妖雾",
        "de": "Unheimlich",
        "en": "Gloom",
        "fr": "Nébuleux",
        "ja": "妖霧",
        "ko": "요마의 안개",
    },
    18: {
        "cn": "极光",
        "de": "Aurora",
        "en": "Auroras",
        "fr": "Aurore",
        "ja": "オーロラ",
        "ko": "오로라",
    },
    19: {
        "cn": "黑暗",
        "de": "Dunkel",
        "en": "Darkness",
        "fr": "Ténèbres",
        "ja": "闇",
        "ko": "어둠",
    },
    20: {
        "cn": "绝命",
        "de": "Düsternis",
        "en": "Tension",
        "fr": "Désespérance",
        "ja": "闘気",
        "ko": "투기",
    },
    21: {
        "cn": "阴云",
        "de": "Wolkig",
        "en": "Clouds",
        "fr": "Couvert",
        "ja": "曇り",
        "ko": "흐림",
    },
    22: {
        "cn": "雷云",
        "de": "Wetterleuchten",
        "en": "Storm Clouds",
        "fr": "Orageux",
        "ja": "雷雲",
        "ko": "뇌운",
    },
    23: {
        "cn": "暴风雨",
        "de": "Tosend",
        "en": "Rough Seas",
        "fr": "Houle",
        "ja": "時化",
        "ko": "파랑",
    },
    24: {
        "cn": "暴风雨",
        "de": "Tosend",
        "en": "Rough Seas",
        "fr": "Houle",
        "ja": "時化",
        "ko": "파랑",
    },
    25: {
        "cn": "阴沉",
        "de": "Finster",
        "en": "Louring",
        "fr": "Nuageux",
        "ja": "曇天",
        "ko": "먹구름",
    },
    26: {
        "cn": "热浪",
        "de": "Gluthitze",
        "en": "Heat Waves",
        "fr": "Torride",
        "ja": "灼熱波",
        "ko": "작열파",
    },
    27: {
        "cn": "妖雾",
        "de": "Unheimlich",
        "en": "Gloom",
        "fr": "Nébuleux",
        "ja": "妖霧",
        "ko": "요마의 안개",
    },
    28: {
        "cn": "暴风",
        "de": "Stürmisch",
        "en": "Gales",
        "fr": "Vents violents",
        "ja": "暴風",
        "ko": "폭풍",
    },
    29: {
        "cn": "烟雾",
        "de": "Rauchschwaden",
        "en": "Eruptions",
        "fr": "Éruptions",
        "ja": "噴煙",
        "ko": "분화",
    },
    30: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    31: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    32: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    33: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    34: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    35: {
        "cn": "极光",
        "de": "Blendend",
        "en": "Irradiance",
        "fr": "Rayonnement",
        "ja": "極光",
        "ko": "극광",
    },
    36: {
        "cn": "辉核",
        "de": "Kernstrahlung",
        "en": "Core Radiation",
        "fr": "Radiations du Cœur",
        "ja": "龍核",
        "ko": "용핵",
    },
    37: {
        "cn": "辉核",
        "de": "Kernstrahlung",
        "en": "Core Radiation",
        "fr": "Radiations du Cœur",
        "ja": "龍核",
        "ko": "용핵",
    },
    38: {
        "cn": "辉核",
        "de": "Kernstrahlung",
        "en": "Core Radiation",
        "fr": "Radiations du Cœur",
        "ja": "龍核",
        "ko": "용핵",
    },
    39: {
        "cn": "辉核",
        "de": "Kernstrahlung",
        "en": "Core Radiation",
        "fr": "Radiations du Cœur",
        "ja": "龍核",
        "ko": "용핵",
    },
    40: {
        "cn": "滩云",
        "de": "Wolkenschleier",
        "en": "Shelf Clouds",
        "fr": "Amas nuageux",
        "ja": "群雲",
        "ko": "떼구름",
    },
    41: {
        "cn": "滩云",
        "de": "Wolkenschleier",
        "en": "Shelf Clouds",
        "fr": "Amas nuageux",
        "ja": "群雲",
        "ko": "떼구름",
    },
    42: {
        "cn": "滩云",
        "de": "Wolkenschleier",
        "en": "Shelf Clouds",
        "fr": "Amas nuageux",
        "ja": "群雲",
        "ko": "떼구름",
    },
    43: {
        "cn": "滩云",
        "de": "Wolkenschleier",
        "en": "Shelf Clouds",
        "fr": "Amas nuageux",
        "ja": "群雲",
        "ko": "떼구름",
    },
    44: {
        "cn": "神意",
        "de": "Bedrückend",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    45: {
        "cn": "神意",
        "de": "Bedrückend",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    46: {
        "cn": "神意",
        "de": "Bedrückend",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    47: {
        "cn": "神意",
        "de": "Bedrückend",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    48: {
        "cn": "神意",
        "de": "Bedrückend",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    49: {
        "cn": "灵风",
        "de": "Schattenwind",
        "en": "Umbral Wind",
        "fr": "Vent ombral",
        "ja": "霊風",
        "ko": "그림자바람",
    },
    50: {
        "cn": "灵电",
        "de": "Schattengewitter",
        "en": "Umbral Static",
        "fr": "Charges ombrales",
        "ja": "放電",
        "ko": "방전",
    },
    51: {
        "cn": "烟武",
        "de": "Qualm",
        "en": "Smoke",
        "fr": "Fumées",
        "ja": "煙霧",
        "ko": "연무",
    },
    52: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    53: {
        "cn": "兽雷",
        "de": "Königsgewitter",
        "en": "Royal Levin",
        "fr": "Éclairs royaux",
        "ja": "獣雷",
        "ko": "야수번개",
    },
    54: {
        "cn": "雷波",
        "de": "Hochspannung",
        "en": "Hyperelectricity",
        "fr": "Hyperélectricité",
        "ja": "雷波",
        "ko": "번개파동",
    },
    55: {
        "cn": "兽雷",
        "de": "Königsgewitter",
        "en": "Royal Levin",
        "fr": "Éclairs royaux",
        "ja": "獣雷",
        "ko": "야수번개",
    },
    56: {
        "cn": "神意",
        "de": "Numinos",
        "en": "Oppression",
        "fr": "Oppression",
        "ja": "神意",
        "ko": "섭리",
    },
    57: {
        "cn": "打雷",
        "de": "Gewittrig",
        "en": "Thunder",
        "fr": "Orages",
        "ja": "雷",
        "ko": "번개",
    },
    58: {
        "cn": "打雷",
        "de": "Gewittrig",
        "en": "Thunder",
        "fr": "Orages",
        "ja": "雷",
        "ko": "번개",
    },
    59: {"cn": None, "de": None, "en": "CutScene", "fr": None, "ja": None, "ko": None},
    60: {
        "cn": "神秘",
        "de": "Mystisch",
        "en": "Multiplicity",
        "fr": "Multiplicité",
        "ja": "神秘",
        "ko": "신비",
    },
    61: {
        "cn": "神秘",
        "de": "Mystisch",
        "en": "Multiplicity",
        "fr": "Multiplicité",
        "ja": "神秘",
        "ko": "신비",
    },
    62: {
        "cn": "小雨",
        "de": "Regnerisch",
        "en": "Rain",
        "fr": "Pluie",
        "ja": "雨",
        "ko": "비",
    },
    63: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    64: {
        "cn": "小雨",
        "de": "Regnerisch",
        "en": "Rain",
        "fr": "Pluie",
        "ja": "雨",
        "ko": "비",
    },
    65: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    66: {
        "cn": "邪天",
        "de": "Hass",
        "en": "Dragonstorms",
        "fr": "Tempête de haine",
        "ja": "邪天",
        "ko": "사룡의 원념",
    },
    67: {
        "cn": "邪天",
        "de": "Hass",
        "en": "Dragonstorms",
        "fr": "Tempête de haine",
        "ja": "邪天",
        "ko": "사룡의 원념",
    },
    68: {
        "cn": "晴朗",
        "de": "Unterirdisch",
        "en": "Subterrain",
        "fr": "Souterrain",
        "ja": "晴れ",
        "ko": "맑음",
    },
    69: {
        "cn": "平衡",
        "de": "Gerechtigkeit",
        "en": "Concordance",
        "fr": "Harmonie",
        "ja": "調和",
        "ko": "조화",
    },
    70: {
        "cn": "平衡",
        "de": "Gerechtigkeit",
        "en": "Concordance",
        "fr": "Harmonie",
        "ja": "調和",
        "ko": "조화",
    },
    71: {
        "cn": "时光",
        "de": "Zeitfluss",
        "en": "Beyond Time",
        "fr": "Hors du temps",
        "ja": "時流",
        "ko": "시류",
    },
    72: {
        "cn": "时光",
        "de": "Zeitfluss",
        "en": "Beyond Time",
        "fr": "Hors du temps",
        "ja": "時流",
        "ko": "시류",
    },
    73: {
        "cn": "时光",
        "de": "Zeitfluss",
        "en": "Beyond Time",
        "fr": "Hors du temps",
        "ja": "時流",
        "ko": "시류",
    },
    74: {
        "cn": "鬼气",
        "de": "Dämonisch unendlich",
        "en": "Demonic Infinity",
        "fr": "Infini démoniaque",
        "ja": "鬼気",
        "ko": "귀기",
    },
    75: {
        "cn": "鬼气",
        "de": "Dämonisch unendlich",
        "en": "Demonic Infinity",
        "fr": "Infini démoniaque",
        "ja": "鬼気",
        "ko": "귀기",
    },
    76: {
        "cn": "鬼气",
        "de": "Dämonisch unendlich",
        "en": "Demonic Infinity",
        "fr": "Infini démoniaque",
        "ja": "鬼気",
        "ko": "귀기",
    },
    77: {
        "cn": "次元",
        "de": "Dimensionsspaltend",
        "en": "Dimensional Disruption",
        "fr": "Perturbation dimensionnelle",
        "ja": "次元",
        "ko": "차원",
    },
    78: {
        "cn": "次元",
        "de": "Dimensionsspaltend",
        "en": "Dimensional Disruption",
        "fr": "Perturbation dimensionnelle",
        "ja": "次元",
        "ko": "차원",
    },
    79: {
        "cn": "次元",
        "de": "Dimensionsspaltend",
        "en": "Dimensional Disruption",
        "fr": "Perturbation dimensionnelle",
        "ja": "次元",
        "ko": "차원",
    },
    80: {
        "cn": "豪雨",
        "de": "Feiersturm",
        "en": "Revelstorms",
        "fr": "Tempête festive",
        "ja": "嵐天",
        "ko": "호우",
    },
    81: {
        "cn": "豪雨",
        "de": "Feiersturm",
        "en": "Revelstorms",
        "fr": "Tempête festive",
        "ja": "嵐天",
        "ko": "호우",
    },
    82: {
        "cn": "极乐",
        "de": "Ewigschön",
        "en": "Eternal Bliss",
        "fr": "Béatitude éternelle",
        "ja": "美天",
        "ko": "미혹",
    },
    83: {
        "cn": "极乐",
        "de": "Ewigschön",
        "en": "Eternal Bliss",
        "fr": "Béatitude éternelle",
        "ja": "美天",
        "ko": "미혹",
    },
    84: {
        "cn": "龙威",
        "de": "Drachensturm",
        "en": "Wyrmstorms",
        "fr": "Tempête draconique",
        "ja": "龍天",
        "ko": "신룡의 폭풍",
    },
    85: {
        "cn": "龙威",
        "de": "Drachensturm",
        "en": "Wyrmstorms",
        "fr": "Tempête draconique",
        "ja": "龍天",
        "ko": "신룡의 폭풍",
    },
    86: {
        "cn": "豪雨",
        "de": "Feiersturm",
        "en": "Revelstorms",
        "fr": "Tempête festive",
        "ja": "嵐天",
        "ko": "호우",
    },
    87: {
        "cn": "迅雷",
        "de": "Blitzsturm",
        "en": "Quicklevin",
        "fr": "Vif-orage",
        "ja": "迅雷",
        "ko": "전선뇌우",
    },
    88: {
        "cn": "打雷",
        "de": "Gewittrig",
        "en": "Thunder",
        "fr": "Orages",
        "ja": "雷",
        "ko": "번개",
    },
    89: {
        "cn": "次元",
        "de": "Dimensionsspaltend",
        "en": "Dimensional Disruption",
        "fr": "Perturbation dimensionnelle",
        "ja": "次元",
        "ko": "차원",
    },
    90: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    91: {
        "cn": "碧空",
        "de": "Klar",
        "en": "Clear Skies",
        "fr": "Dégagé",
        "ja": "快晴",
        "ko": "쾌청",
    },
    92: {
        "cn": "白旋风",
        "de": "Weißer Zyklon",
        "en": "White Cyclones",
        "fr": "Tempête blanche",
        "ja": "白嵐",
        "ko": "하얀 폭풍",
    },
    93: {
        "cn": "白旋风",
        "de": "Weißer Zyklon",
        "en": "White Cyclones",
        "fr": "Tempête blanche",
        "ja": "白嵐",
        "ko": "하얀 폭풍",
    },
    94: {
        "cn": "白旋风",
        "de": "Weißer Zyklon",
        "en": "White Cyclones",
        "fr": "Tempête blanche",
        "ja": "白嵐",
        "ko": "하얀 폭풍",
    },
    95: {
        "cn": "幻想",
        "de": "Ultimativ",
        "en": "Ultimania",
        "fr": "Fantasmagorique",
        "ja": "幻想",
        "ko": "환상",
    },
    96: {
        "cn": "白旋风",
        "de": "Weißer Zyklon",
        "en": "White Cyclones",
        "fr": "Tempête blanche",
        "ja": "白嵐",
        "ko": "하얀 폭풍",
    },
    97: {
        "cn": "月夜",
        "de": "Dunkle Mondnacht",
        "en": "Moonlight",
        "fr": "Clair de lune",
        "ja": "月夜",
        "ko": "달빛",
    },
    98: {
        "cn": "月夜",
        "de": "Dunkle Mondnacht",
        "en": "Moonlight",
        "fr": "Clair de lune",
        "ja": "月夜",
        "ko": "달빛",
    },
    99: {
        "cn": "月夜",
        "de": "Dunkle Mondnacht",
        "en": "Moonlight",
        "fr": "Clair de lune",
        "ja": "月夜",
        "ko": "달빛",
    },
    100: {
        "cn": "月夜",
        "de": "Dunkle Mondnacht",
        "en": "Moonlight",
        "fr": "Clair de lune",
        "ja": "月夜",
        "ko": "달빛",
    },
    101: {
        "cn": "红月下",
        "de": "Roter Mond",
        "en": "Red Moon",
        "fr": "Lune rouge",
        "ja": "紅月下",
        "ko": "붉은 달",
    },
    102: {
        "cn": "朱炎",
        "de": "Rotlodernd",
        "en": "Scarlet",
        "fr": "Vermillon",
        "ja": "朱炎",
        "ko": "붉은 불꽃 ",
    },
    103: {
        "cn": "朱炎",
        "de": "Rotlodernd",
        "en": "Scarlet",
        "fr": "Vermillon",
        "ja": "朱炎",
        "ko": "붉은 불꽃 ",
    },
    104: {
        "cn": "朱炎",
        "de": "Rotlodernd",
        "en": "Scarlet",
        "fr": "Vermillon",
        "ja": "朱炎",
        "ko": "붉은 불꽃 ",
    },
    105: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    106: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    107: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    108: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    109: {
        "cn": "烈焰",
        "de": "Feuer",
        "en": "Flames",
        "fr": "Flammes",
        "ja": "火炎",
        "ko": "화염",
    },
    110: {
        "cn": "海啸",
        "de": "Tsunami",
        "en": "Tsunamis",
        "fr": "Raz-de-marée",
        "ja": "津波",
        "ko": "해일",
    },
    111: {
        "cn": "龙卷风",
        "de": "Tornado",
        "en": "Cyclones",
        "fr": "Tornade",
        "ja": "竜巻",
        "ko": "회오리",
    },
    112: {
        "cn": "地震",
        "de": "Erdbeben",
        "en": "Geostorms",
        "fr": "Séisme",
        "ja": "地震",
        "ko": "지진",
    },
    113: {
        "cn": "青空",
        "de": "Blauschimmernd",
        "en": "True Blue",
        "fr": "Azur",
        "ja": "青春",
        "ko": "푸른 봄날",
    },
    114: {
        "cn": "青空",
        "de": "Blauschimmernd",
        "en": "True Blue",
        "fr": "Azur",
        "ja": "青春",
        "ko": "푸른 봄날",
    },
    115: {
        "cn": "青空",
        "de": "Blauschimmernd",
        "en": "True Blue",
        "fr": "Azur",
        "ja": "青春",
        "ko": "푸른 봄날",
    },
    116: {
        "cn": "乱灵流",
        "de": "Astrale Turbulenzen",
        "en": "Umbral Turbulence",
        "fr": "Turbulences ombrales",
        "ja": "乱霊流",
        "ko": "난령류",
    },
    117: {
        "cn": "青空",
        "de": "Blauschimmernd",
        "en": "True Blue",
        "fr": "Azur",
        "ja": "青春",
        "ko": "푸른 봄날",
    },
    118: {
        "cn": "无尽光",
        "de": "Ewiges Licht",
        "en": "Everlasting Light",
        "fr": "Clarté éternelle",
        "ja": "無尽光",
        "ko": "끝없는 빛",
    },
    119: {
        "cn": "暴风",
        "de": "Stürmisch",
        "en": "Gales",
        "fr": "Vents violents",
        "ja": "暴風",
        "ko": "폭풍",
    },
    120: {
        "cn": "末日",
        "de": "Apokalyptisch",
        "en": "Termination",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    121: {
        "cn": "末日",
        "de": "Apokalyptisch",
        "en": "Termination",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    122: {
        "cn": "妖梦",
        "de": "Feenträume",
        "en": "Dreams",
        "fr": "Rêverie",
        "ja": "妖夢",
        "ko": "이상한 꿈",
    },
    123: {
        "cn": "妖梦",
        "de": "Feenträume",
        "en": "Dreams",
        "fr": "Rêverie",
        "ja": "妖夢",
        "ko": "이상한 꿈",
    },
    124: {
        "cn": "妖梦",
        "de": "Feenträume",
        "en": "Dreams",
        "fr": "Rêverie",
        "ja": "妖夢",
        "ko": "이상한 꿈",
    },
    125: {
        "cn": "光天",
        "de": "Strahlende Glanzhaftigkeit",
        "en": "Brilliance",
        "fr": "Radiance divine",
        "ja": "光天",
        "ko": "눈부신 하늘",
    },
    126: {
        "cn": "光天",
        "de": "Strahlende Glanzhaftigkeit",
        "en": "Brilliance",
        "fr": "Radiance divine",
        "ja": "光天",
        "ko": "눈부신 하늘",
    },
    127: {
        "cn": "末日",
        "de": "Apokalyptisch",
        "en": "Termination",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    128: {
        "cn": "末日",
        "de": "Apokalyptisch",
        "en": "Termination",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    129: {
        "cn": "无尽光",
        "de": "Ewiges Licht",
        "en": "Everlasting Light",
        "fr": "Clarté éternelle",
        "ja": "無尽光",
        "ko": "끝없는 빛",
    },
    130: {
        "cn": "烟雾",
        "de": "Rauchschwaden",
        "en": "Eruptions",
        "fr": "Éruptions",
        "ja": "噴煙",
        "ko": "분화",
    },
    131: {
        "cn": "末日",
        "de": "Apokalyptisch",
        "en": "Termination",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    132: {
        "cn": "晴朗",
        "de": "Heiter",
        "en": "Fair Skies",
        "fr": "Clair",
        "ja": "晴れ",
        "ko": "맑음",
    },
    133: {
        "cn": "灵烈火",
        "de": "Feuerseelenwinde",
        "en": "Umbral Flare",
        "fr": "Vent ombral de feu",
        "ja": "焔霊風",
        "ko": "화속성풍",
    },
    134: {
        "cn": "灵飘尘",
        "de": "Erdseelenwinde",
        "en": "Umbral Duststorm",
        "fr": "Vent ombral de terre",
        "ja": "土霊風",
        "ko": "토속성풍",
    },
    135: {
        "cn": "灵飞电",
        "de": "Donnerseelenwinde",
        "en": "Umbral Levin",
        "fr": "Vent ombral de foudre",
        "ja": "雷霊風",
        "ko": "뇌속성풍",
    },
    136: {
        "cn": "灵罡风",
        "de": "Sturmseelenwinde",
        "en": "Umbral Tempest",
        "fr": "Vent ombral des tempêtes",
        "ja": "嵐霊風",
        "ko": "풍속성풍",
    },
    137: {
        "cn": "流星雨",
        "de": "Sternenregen",
        "en": "Starshower",
        "fr": "Pluie d'étoiles",
        "ja": "流星雨",
        "ko": "유성우",
    },
    138: {
        "cn": "记忆乱流",
        "de": "Erinnerungsturbulenzen",
        "en": "Delirium",
        "fr": "Tempête de souvenirs",
        "ja": "記憶乱流",
        "ko": "기억난류",
    },
    139: {
        "cn": "阴云",
        "de": "Wolkig",
        "en": "Clouds",
        "fr": "Couvert",
        "ja": "曇り",
        "ko": "흐림",
    },
    140: {
        "cn": "阴云",
        "de": "Wolkig",
        "en": "Clouds",
        "fr": "Couvert",
        "ja": "曇り",
        "ko": "흐림",
    },
    141: {
        "cn": "极光",
        "de": "Blendend",
        "en": "Irradiance",
        "fr": "Rayonnement",
        "ja": "極光",
        "ko": "극광",
    },
    142: {
        "cn": "极光",
        "de": "Blendend",
        "en": "Irradiance",
        "fr": "Rayonnement",
        "ja": "極光",
        "ko": "극광",
    },
    143: {
        "cn": "雷云",
        "de": "Wetterleuchten",
        "en": "Storm Clouds",
        "fr": "Orageux",
        "ja": "雷雲",
        "ko": "뇌운",
    },
    144: {
        "cn": "火风暴",
        "de": "Flammensturm",
        "en": "Firestorm",
        "fr": "Tempête de feu",
        "ja": "焔嵐\xa0",
        "ko": "불바람",
    },
    145: {
        "cn": "幻海流",
        "de": "Phantomströmung",
        "en": "Spectral Current",
        "fr": "Courant spectral",
        "ja": "幻海流\xa0",
        "ko": "환해류",
    },
    146: {"cn": None, "de": None, "en": None, "fr": None, "ja": None, "ko": None},
    147: {
        "cn": "决战",
        "de": "Endzeitig",
        "en": "Climactic",
        "fr": "Fatidique",
        "ja": "決戦",
        "ko": "결전",
    },
    148: {
        "cn": "月尘",
        "de": "Mondstaubig",
        "en": "Moon Dust",
        "fr": "Tempêtes de régolithe",
        "ja": "月砂塵",
        "ko": "달모래먼지",
    },
    149: {
        "cn": "磁暴",
        "de": "Magnetsturm",
        "en": "Astromagnetic Storm",
        "fr": "Astromagnétique",
        "ja": "磁気嵐",
        "ko": "자기장 폭풍",
    },
    150: {
        "cn": "末日",
        "de": "Apokalypse",
        "en": "Apocalypse",
        "fr": "Apocalypse",
        "ja": "終末",
        "ko": "종말",
    },
    151: {
        "cn": "星灵",
        "de": "Polarisierend",
        "en": "Polarization",
        "fr": "Polarisation",
        "ja": "星霊",
        "ko": "별빛그림자",
    },
    152: {
        "cn": "星灵",
        "de": "Polarisierend",
        "en": "Polarization",
        "fr": "Polarisation",
        "ja": "星霊",
        "ko": "별빛그림자",
    },
    153: {
        "cn": "星灵",
        "de": "Polarisierend",
        "en": "Polarization",
        "fr": "Polarisation",
        "ja": "星霊",
        "ko": "별빛그림자",
    },
    154: {
        "cn": "星灵",
        "de": "Polarisierend",
        "en": "Polarization",
        "fr": "Polarisation",
        "ja": "星霊",
        "ko": "별빛그림자",
    },
    155: {
        "cn": "星灵",
        "de": "Polarisierend",
        "en": "Polarization",
        "fr": "Polarisation",
        "ja": "星霊",
        "ko": "별빛그림자",
    },
    156: {
        "cn": "虚拟",
        "de": "Imaginär",
        "en": "Projection",
        "fr": "Virtuel",
        "ja": "仮想",
        "ko": "가상",
    },
    157: {
        "cn": "万魔殿",
        "de": "Pandæmonium",
        "en": "Pandæmonium",
        "fr": "Pandæmonium",
        "ja": "万魔殿",
        "ko": "마의 전당",
    },
    158: {
        "cn": "万魔殿",
        "de": "Pandæmonium",
        "en": "Pandæmonium",
        "fr": "Pandæmonium",
        "ja": "万魔殿",
        "ko": "마의 전당",
    },
    159: {
        "cn": "万魔殿",
        "de": "Pandæmonium",
        "en": "Pandæmonium",
        "fr": "Pandæmonium",
        "ja": "万魔殿",
        "ko": "마의 전당",
    },
    160: {
        "cn": "终极",
        "de": "Eschatologie",
        "en": "Ultimatum",
        "fr": "Eschatologique",
        "ja": "終極",
        "ko": "종극",
    },
    161: {
        "cn": "绝望",
        "de": "Verzweifelnd",
        "en": "Inevitability",
        "fr": "Désespoir",
        "ja": "絶望",
        "ko": "절망",
    },
    162: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    163: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    164: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    165: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    166: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    167: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    168: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    169: {
        "cn": "神域",
        "de": "Götterwetter",
        "en": "Transcendence",
        "fr": "Mythologique",
        "ja": "神域",
        "ko": None,
    },
    170: {
        "cn": "邪天",
        "de": "Hass",
        "en": "Dragonstorms",
        "fr": "Tempête de haine",
        "ja": "邪天",
        "ko": None,
    },
    171: {
        "cn": None,
        "de": "Leere",
        "en": "Vacuity",
        "fr": "Néant",
        "ja": "虚無",
        "ko": None,
    },
    172: {
        "cn": None,
        "de": "Leere",
        "en": "Vacuity",
        "fr": "Néant",
        "ja": "虚無",
        "ko": None,
    },
    173: {
        "cn": None,
        "de": "Leere",
        "en": "Vacuity",
        "fr": "Néant",
        "ja": "虚無",
        "ko": None,
    },
}
